@@ -26,6 +26,13 @@ class Project:
         'EDB_DEPLOY_DIR',
         os.path.join(os.path.expanduser("~"), ".edb-deployment")
     )
+    # Path that should contain 3rd party tools binaries when they are installed
+    # by the prerequisites installation script.
+    cloud_tools_bin_path = os.path.join(
+        os.path.expanduser("~"),
+        '.edb-cloud-tools',
+        'bin'
+    )
     terraform_share_path = os.path.join(
         os.path.dirname(os.path.realpath(__file__)),
         'data',
@@ -78,6 +85,18 @@ class Project:
         )
         self.state_file = os.path.join(self.project_path, 'state.json')
 
+    def check_versions(self):
+        # Check Ansible version
+        ansible = AnsibleCli('dummy', bin_path=self.cloud_tools_bin_path)
+        ansible.check_version()
+        # Check Terraform version
+        terraform = TerraformCli('dummy', 'dummy',
+                                 bin_path=self.cloud_tools_bin_path)
+        terraform.check_version()
+        # Check cloud vendor CLI/SDK version
+        cloud_cli = CloudCli(self.cloud, bin_path=self.cloud_tools_bin_path)
+        cloud_cli.check_version()
+
     def create_log_dir(self):
         try:
             os.makedirs(os.path.dirname(self.log_file))
@@ -169,6 +188,13 @@ class Project:
 
         # Copy SSH keys
         with AM("Copying SSH key pair into %s" % self.project_path):
+
+            # Ensure SSH keys have been defined
+            if env.ssh_priv_key is None:
+                raise ProjectError("SSH private key not defined")
+            if env.ssh_pub_key is None:
+                raise ProjectError("SSH public key not defined")
+
             shutil.copy(env.ssh_priv_key.name, self.ssh_priv_key)
             shutil.copy(env.ssh_pub_key.name, self.ssh_pub_key)
             os.chmod(self.ssh_priv_key, stat.S_IREAD | stat.S_IWRITE)
@@ -215,7 +241,7 @@ class Project:
             )
 
         # Instanciate a new CloudCli
-        cloud_cli = CloudCli(env.cloud)
+        cloud_cli = CloudCli(env.cloud, bin_path=self.cloud_tools_bin_path)
 
         # Build a list of instance_type accordingly to the specs
         instance_types = []
@@ -456,8 +482,8 @@ class Project:
             pg_type=env.postgres_type,
             pg_version=env.postgres_version,
             efm_version=env.efm_version,
-            yum_username=edb_repo_username,
-            yum_password=edb_repo_password,
+            repo_username=edb_repo_username,
+            repo_password=edb_repo_password,
             ssh_user=os_spec['ssh_user'],
             ssh_priv_key=self.ssh_priv_key
         )
@@ -490,7 +516,8 @@ class Project:
 
     def remove(self):
         terraform = TerraformCli(
-            self.project_path, self.terraform_plugin_cache_path
+            self.project_path, self.terraform_plugin_cache_path,
+            bin_path=self.cloud_tools_bin_path
         )
         # Prevent project deletion if some cloud resources are still present
         # for this project.
@@ -529,7 +556,8 @@ class Project:
 
     def provision(self):
         terraform = TerraformCli(
-            self.project_path, self.terraform_plugin_cache_path
+            self.project_path, self.terraform_plugin_cache_path,
+            bin_path=self.cloud_tools_bin_path
         )
 
         self.update_state('terraform', 'INITIALIZATING')
@@ -543,7 +571,7 @@ class Project:
         self.update_state('terraform', 'PROVISIONED')
 
         # Checking instance availability
-        cloud_cli = CloudCli(self.cloud)
+        cloud_cli = CloudCli(self.cloud, bin_path=self.cloud_tools_bin_path)
         self._load_terraform_vars()
 
         # AWS case
@@ -581,7 +609,8 @@ class Project:
 
     def destroy(self):
         terraform = TerraformCli(
-            self.project_path, self.terraform_plugin_cache_path
+            self.project_path, self.terraform_plugin_cache_path,
+            bin_path=self.cloud_tools_bin_path
         )
 
         self.update_state('terraform', 'DESTROYING')
@@ -592,7 +621,10 @@ class Project:
 
     def deploy(self, no_install_collection):
         inventory_data = None
-        ansible = AnsibleCli(self.project_path)
+        ansible = AnsibleCli(
+            self.project_path,
+            bin_path = self.cloud_tools_bin_path
+        )
 
         # Load ansible vars
         self._load_ansible_vars()
@@ -610,8 +642,8 @@ class Project:
             pg_type=self.ansible_vars['pg_type'],
             pg_version=self.ansible_vars['pg_version'],
             efm_version=self.ansible_vars['efm_version'],
-            yum_username=self.ansible_vars['yum_username'],
-            yum_password=self.ansible_vars['yum_password'],
+            repo_username=self.ansible_vars['repo_username'],
+            repo_password=self.ansible_vars['repo_password'],
             pass_dir=os.path.join(self.project_path, '.edbpass')
         )
         if self.ansible_vars.get('pg_data'):
@@ -680,7 +712,10 @@ class Project:
             if status == 'DEPLOYING':
                 print("WARNING: project is in deploying state")
             inventory_data = None
-            ansible = AnsibleCli(self.project_path)
+            ansible = AnsibleCli(
+                self.project_path,
+                bin_path = self.cloud_tools_bin_path
+            )
             with AM("Extracting data from the inventory file"):
                 inventory_data = ansible.list_inventory(self.ansible_inventory)
             self.display_inventory(inventory_data)
@@ -749,7 +784,8 @@ class Project:
                 terraform_resource_count = 0
                 terraform = TerraformCli(
                     project.project_path,
-                    project.terraform_plugin_cache_path
+                    project.terraform_plugin_cache_path,
+                    bin_path=Project.cloud_tools_bin_path
                 )
                 terraform_resource_count = terraform.count_resources()
 
